@@ -6,16 +6,14 @@ from netbox_storage.models import LogicalVolume
 
 
 class LogicalVolumeFilter(NetBoxModelFilterSet):
-    """Filter capabilities for LogicalVolume instances."""
-
     class Meta:
         model = LogicalVolume
         fields = [
+            "vg",
             "lv_name",
             "size",
-            "path",
+            "device",
             "description",
-            "storage_configuration"
         ]
 
     def search(self, queryset, name, value):
@@ -23,8 +21,8 @@ class LogicalVolumeFilter(NetBoxModelFilterSet):
         if not value.strip():
             return queryset
         qs_filter = (
-            Q(lv_name__icontains=value)
-            | Q(size__icontains=value)
-            | Q(path__icontains=value)
+                Q(lv_name__icontains=value)
+                | Q(size__icontains=value)
+                | Q(description__icontains=value)
         )
         return queryset.filter(qs_filter)
