@@ -107,7 +107,6 @@ class LVMTemplateForm(NetBoxModelForm):
         print(f"Device Name: {device_name_prefix}")
 
         linux_parent_device = LinuxDevice.objects.get(device=device_name_prefix)
-        pv_linux_device = None
         if self.cleaned_data['checkbox_partition']:
             device_name = device_name_prefix + str(1)
             linuxdevice_type_pk = ContentType.objects.get(app_label='netbox_storage', model='linuxdevice').pk
@@ -116,12 +115,10 @@ class LVMTemplateForm(NetBoxModelForm):
                                                          size=linux_parent_device.size,
                                                          object_id=linux_parent_device.pk,
                                                          content_type_id=linuxdevice_type_pk)
-            pv_linux_device.save()
         else:
             pv_linux_device = linux_parent_device
 
         volume_group = VolumeGroup.objects.create(vg_name=self.cleaned_data['vg_name'])
-        volume_group.save()
         #print(f"Volume Group ID: {volume_group.id}")
 
         #pv = PhysicalVolume.objects.create(device=pv_linux_device, vg=volume_group)
@@ -129,13 +126,12 @@ class LVMTemplateForm(NetBoxModelForm):
         #print(f"Physical Volume ID: {pv.id}")
 
         # Add linux_device for lvm
-        pv_type_pk = ContentType.objects.get(app_label='netbox_storage', model='volumegroup').pk
+        pv_type_pk = ContentType.objects.get(app_label='netbox_storage', model='physicalvolume').pk
         linux_device_mapper = LinuxDevice.objects.create(device='/dev/mapper/vg_system-lv_home',
                                                          type='LVM',
                                                          size=pv_linux_device.size,
-                                                         object_id=volume_group.pk,
+                                                         object_id=pv.pk,
                                                          content_type_id=pv_type_pk)
-        linux_device_mapper.save()
         #print(f"Linux Device ID: {linux_device_mapper.id}")
 
         self.instance.vg = volume_group
